/**
 * Triple is a pythagorean triple.
 * @author jdalbey
 */
public class Triple
{ 
    // factor-pair from Euclid's formula
    private int m;
    private int n;

    /** Construct a triple from initial values for m and n.
     * @param initialM the value of m
     * @param initialN the value of n
     * @pre Assumes initialM > 0, initialN > 0, initialM > initialN
     */     
    public Triple(int initialM, int initialN)
    {
        this.m = initialM;
        this.n = initialN;
    }
    
    /** Compute Side 1.
     * @return the length of side 1
     */
    public long findSide1()
    {
        return (long)m * (long)m - (long)n * (long)n;
    }

    /** Compute Side 2.
     * @return the length of side 2
     */
    public long findSide2()
    {
        return 2 * (long)m * (long)n;
    }
    
    /** Compute Side 3 (the hypotenuse).
     * @return the length of the hypotenuse
     */
    public long findHypotenuse()
    {
        return (long)m * (long)m + (long)n * (long)n;
    }
    
    /** Add the given Triple to this one.
     * Let's define addition as M+M,N+N
     *
     * @param Triple another Triple
     * @return the sum of the two triples
     */
    public Triple add(Triple other)
    {
        return new Triple(this.m + other.m, this.n + other.n);
    }

    /** Return a string representation of the factors of this Triple.
     * @return String representation of the factors [m,n]
     */
    public String getFactors()
    {
        return "[" + m + "," + n + "]";
    }

    /** Return a string representation of this Triple.
     * @return String representation of this Triple.
     */
    public String toString()
    {
        return "["+findSide1()+","+findSide2()+","+findHypotenuse()+"]";
    }
}
